package app18b.dao;

import app18b.util.Config;

public class DAOFactory {
  private static String databaseType;
  private static DAOFactory instance;
  
  static {
  	instance = new DAOFactory();  
  }
  private DAOFactory() {
    databaseType = Config.getInstance().getValue("dbType").toString();
  }
  public static DAOFactory getInstance() {
    return instance;
  }
  
  public CustomerDAO getCustomerDAO() {
    String className = null;
    if (databaseType!=null) {
      if (databaseType.equalsIgnoreCase("mysql")) {         
        className = "app18b.dao.CustomerDAOMySQLImpl"; 
      }
      else if (databaseType.equalsIgnoreCase("oracle")) {
        className = "app18b.dao.CustomerDAOOracleImpl";
      }
    }
    if (className==null)
      return null;
    CustomerDAO customerDAO = null;
    Class clazz = null;
    try {
      clazz = Class.forName(className);
    }
    catch (ClassNotFoundException e) {
      System.out.println(e.toString());
    }
    if (clazz!=null) {
      try {
        customerDAO = (CustomerDAO) clazz.newInstance();
      }
      catch (Exception e) {
          System.out.println(e.toString());
      }
    }
    return customerDAO;  
  }
}

